==> jc-1.4.0.tar.gz: java/awt/dnd/DragSourceEvent.h <==
// public class java.awt.dnd.DragSourceEvent

// class file dependencies
// @dep_class 8fa38a35dead9728 java_awt_dnd_DragSourceEvent
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_java_awt_dnd_DragSourceEvent_H_
#define _JC_java_awt_dnd_DragSourceEvent_H_

// Forward structure declarations
struct _jc_java_awt_Point$object;
struct _jc_java_awt_dnd_DragSourceContext$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_dnd_DragSourceEvent$sub_refs	_jc_java_awt_dnd_DragSourceEvent$sub_refs;
typedef struct _jc_java_awt_dnd_DragSourceEvent$sub_nonrefs	_jc_java_awt_dnd_DragSourceEvent$sub_nonrefs;
typedef struct _jc_java_awt_dnd_DragSourceEvent$refs	_jc_java_awt_dnd_DragSourceEvent$refs;
typedef struct _jc_java_awt_dnd_DragSourceEvent$nonrefs	_jc_java_awt_dnd_DragSourceEvent$nonrefs;
typedef struct _jc_java_awt_dnd_DragSourceEvent$object	_jc_java_awt_dnd_DragSourceEvent$object;

typedef struct _jc_java_awt_dnd_DragSourceEvent$fields_struct	_jc_java_awt_dnd_DragSourceEvent$fields_struct;
typedef const struct _jc_java_awt_dnd_DragSourceEvent$vmethods	_jc_java_awt_dnd_DragSourceEvent$vmethods;
typedef const struct _jc_java_awt_dnd_DragSourceEvent$vtable	_jc_java_awt_dnd_DragSourceEvent$vtable;
typedef const struct _jc_java_awt_dnd_DragSourceEvent$vtype	_jc_java_awt_dnd_DragSourceEvent$vtype;

// Class fields structure
struct _jc_java_awt_dnd_DragSourceEvent$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_dnd_DragSourceEvent$fields_struct _jc_java_awt_dnd_DragSourceEvent$class_fields;

// Constructors
extern void _jc_java_awt_dnd_DragSourceEvent$method$_init$64d9ad50fc3f446f(_jc_env *, struct _jc_java_awt_dnd_DragSourceEvent$object *, struct _jc_java_awt_dnd_DragSourceContext$object *);
extern void _jc_java_awt_dnd_DragSourceEvent$method$_init$7495fc7a3cb98d95(_jc_env *, struct _jc_java_awt_dnd_DragSourceEvent$object *, struct _jc_java_awt_dnd_DragSourceContext$object *, jint, jint);

// Virtual methods
extern struct _jc_java_awt_dnd_DragSourceContext$object *_jc_java_awt_dnd_DragSourceEvent$method$getDragSourceContext$ba769f536194ae06(_jc_env *, struct _jc_java_awt_dnd_DragSourceEvent$object *);
extern struct _jc_java_awt_Point$object *_jc_java_awt_dnd_DragSourceEvent$method$getLocation$d1bc48ab096da51c(_jc_env *, struct _jc_java_awt_dnd_DragSourceEvent$object *);
extern jint _jc_java_awt_dnd_DragSourceEvent$method$getX$95f81a17f95fa138(_jc_env *, struct _jc_java_awt_dnd_DragSourceEvent$object *);
extern jint _jc_java_awt_dnd_DragSourceEvent$method$getY$848e5d443e3420a7(_jc_env *, struct _jc_java_awt_dnd_DragSourceEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_dnd_DragSourceEvent$method_info$getDragSourceContext$ba769f536194ae06;
extern _jc_method _jc_java_awt_dnd_DragSourceEvent$method_info$getLocation$d1bc48ab096da51c;
extern _jc_method _jc_java_awt_dnd_DragSourceEvent$method_info$getX$95f81a17f95fa138;
extern _jc_method _jc_java_awt_dnd_DragSourceEvent$method_info$getY$848e5d443e3420a7;

// Virtual methods structure
struct _jc_java_awt_dnd_DragSourceEvent$vmethods {
	struct _jc_java_awt_dnd_DragSourceContext$object	*(*getDragSourceContext$ba769f536194ae06)(_jc_env *, struct _jc_java_awt_dnd_DragSourceEvent$object *);
	struct _jc_java_awt_Point$object	*(*getLocation$d1bc48ab096da51c)(_jc_env *, struct _jc_java_awt_dnd_DragSourceEvent$object *);
	jint	(*getX$95f81a17f95fa138)(_jc_env *, struct _jc_java_awt_dnd_DragSourceEvent$object *);
	jint	(*getY$848e5d443e3420a7)(_jc_env *, struct _jc_java_awt_dnd_DragSourceEvent$object *);
};

// Vtable
struct _jc_java_awt_dnd_DragSourceEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_awt_dnd_DragSourceEvent$vmethods	java_awt_dnd_DragSourceEvent;
};

// Vtype
struct _jc_java_awt_dnd_DragSourceEvent$vtype {
	_jc_type			type;
	_jc_java_awt_dnd_DragSourceEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_dnd_DragSourceEvent$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_dnd_DragSourceEvent$refs {
    _jc_java_awt_dnd_DragSourceEvent$sub_refs	java_awt_dnd_DragSourceEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_dnd_DragSourceEvent$sub_nonrefs {
	jboolean	locationSpecified;
	jint	x;
	jint	y;
};

// Non-reference instance fields (object)
struct _jc_java_awt_dnd_DragSourceEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_awt_dnd_DragSourceEvent$sub_nonrefs	java_awt_dnd_DragSourceEvent;
};

// Object instance structure
struct _jc_java_awt_dnd_DragSourceEvent$object {
	_jc_java_awt_dnd_DragSourceEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_dnd_DragSourceEvent$vtype	*vtype;
	_jc_java_awt_dnd_DragSourceEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_dnd_DragSourceEvent$vtype _jc_java_awt_dnd_DragSourceEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_dnd_DragSourceEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_dnd_DragSourceEvent$class_object;

#endif	/* _JC_java_awt_dnd_DragSourceEvent_H_ */

==> jc-1.4.6.tar.gz: java/awt/dnd/DragSourceEvent.h <==
// public class java.awt.dnd.DragSourceEvent

// class file dependencies
// @dep_class 8fa38a35dead9728 java_awt_dnd_DragSourceEvent
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_java_awt_dnd_DragSourceEvent_H_
#define _JC_java_awt_dnd_DragSourceEvent_H_

// Forward structure declarations
struct _jc_java_awt_Point$object;
struct _jc_java_awt_dnd_DragSourceContext$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_dnd_DragSourceEvent$sub_refs	_jc_java_awt_dnd_DragSourceEvent$sub_refs;
typedef struct _jc_java_awt_dnd_DragSourceEvent$sub_nonrefs	_jc_java_awt_dnd_DragSourceEvent$sub_nonrefs;
typedef struct _jc_java_awt_dnd_DragSourceEvent$refs	_jc_java_awt_dnd_DragSourceEvent$refs;
typedef struct _jc_java_awt_dnd_DragSourceEvent$nonrefs	_jc_java_awt_dnd_DragSourceEvent$nonrefs;
typedef struct _jc_java_awt_dnd_DragSourceEvent$object	_jc_java_awt_dnd_DragSourceEvent$object;

typedef struct _jc_java_awt_dnd_DragSourceEvent$fields_struct	_jc_java_awt_dnd_DragSourceEvent$fields_struct;
typedef const struct _jc_java_awt_dnd_DragSourceEvent$vmethods	_jc_java_awt_dnd_DragSourceEvent$vmethods;
typedef const struct _jc_java_awt_dnd_DragSourceEvent$vtable	_jc_java_awt_dnd_DragSourceEvent$vtable;
typedef const struct _jc_java_awt_dnd_DragSourceEvent$vtype	_jc_java_awt_dnd_DragSourceEvent$vtype;

// Class fields structure
struct _jc_java_awt_dnd_DragSourceEvent$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_dnd_DragSourceEvent$fields_struct _jc_java_awt_dnd_DragSourceEvent$class_fields;

// Constructors
extern void _jc_java_awt_dnd_DragSourceEvent$method$_init$64d9ad50fc3f446f(_jc_env *, struct _jc_java_awt_dnd_DragSourceEvent$object *, struct _jc_java_awt_dnd_DragSourceContext$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_dnd_DragSourceEvent$method$_init$7495fc7a3cb98d95(_jc_env *, struct _jc_java_awt_dnd_DragSourceEvent$object *, struct _jc_java_awt_dnd_DragSourceContext$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_awt_dnd_DragSourceContext$object *_jc_java_awt_dnd_DragSourceEvent$method$getDragSourceContext$ba769f536194ae06(_jc_env *, struct _jc_java_awt_dnd_DragSourceEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Point$object *_jc_java_awt_dnd_DragSourceEvent$method$getLocation$d1bc48ab096da51c(_jc_env *, struct _jc_java_awt_dnd_DragSourceEvent$object *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_dnd_DragSourceEvent$method$getX$95f81a17f95fa138(_jc_env *, struct _jc_java_awt_dnd_DragSourceEvent$object *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_dnd_DragSourceEvent$method$getY$848e5d443e3420a7(_jc_env *, struct _jc_java_awt_dnd_DragSourceEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_dnd_DragSourceEvent$method_info$getDragSourceContext$ba769f536194ae06;
extern _jc_method _jc_java_awt_dnd_DragSourceEvent$method_info$getLocation$d1bc48ab096da51c;
extern _jc_method _jc_java_awt_dnd_DragSourceEvent$method_info$getX$95f81a17f95fa138;
extern _jc_method _jc_java_awt_dnd_DragSourceEvent$method_info$getY$848e5d443e3420a7;

// Virtual methods structure
struct _jc_java_awt_dnd_DragSourceEvent$vmethods {
	struct _jc_java_awt_dnd_DragSourceContext$object	*(*getDragSourceContext$ba769f536194ae06)(_jc_env *, struct _jc_java_awt_dnd_DragSourceEvent$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Point$object	*(*getLocation$d1bc48ab096da51c)(_jc_env *, struct _jc_java_awt_dnd_DragSourceEvent$object *) _JC_JCNI_ATTR;
	jint	(*getX$95f81a17f95fa138)(_jc_env *, struct _jc_java_awt_dnd_DragSourceEvent$object *) _JC_JCNI_ATTR;
	jint	(*getY$848e5d443e3420a7)(_jc_env *, struct _jc_java_awt_dnd_DragSourceEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_dnd_DragSourceEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_awt_dnd_DragSourceEvent$vmethods	java_awt_dnd_DragSourceEvent;
};

// Vtype
struct _jc_java_awt_dnd_DragSourceEvent$vtype {
	_jc_type			type;
	_jc_java_awt_dnd_DragSourceEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_dnd_DragSourceEvent$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_dnd_DragSourceEvent$refs {
    _jc_java_awt_dnd_DragSourceEvent$sub_refs	java_awt_dnd_DragSourceEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_dnd_DragSourceEvent$sub_nonrefs {
	jboolean	locationSpecified;
	jint	x;
	jint	y;
};

// Non-reference instance fields (object)
struct _jc_java_awt_dnd_DragSourceEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_awt_dnd_DragSourceEvent$sub_nonrefs	java_awt_dnd_DragSourceEvent;
};

// Object instance structure
struct _jc_java_awt_dnd_DragSourceEvent$object {
	_jc_java_awt_dnd_DragSourceEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_dnd_DragSourceEvent$vtype	*vtype;
	_jc_java_awt_dnd_DragSourceEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_dnd_DragSourceEvent$vtype _jc_java_awt_dnd_DragSourceEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_dnd_DragSourceEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_dnd_DragSourceEvent$class_object;

#endif	/* _JC_java_awt_dnd_DragSourceEvent_H_ */
